@@ -72,7 +72,7 @@ will be absent if the information isn't available:
 
 =item size
 
-Size of the glyphs in points.
+Size of the glyphs in points.  Only available with Freetype 2.1.5 or newer.
 
 =item height
 
@@ -85,10 +85,12 @@ Width of the bitmaps in pixels.
 =item x_res_dpi, y_res_dpi
 
 Resolution the bitmaps were designed for, in dots per inch.
+Only available with Freetype 2.1.5 or newer.
 
 =item x_res_ppem, y_res_ppem
 
 Resolution the bitmaps were designed for, in pixels per em.
+Only available with Freetype 2.1.5 or newer.
 
 =back
 
@@ -96,15 +98,22 @@ Resolution the bitmaps were designed for, in pixels per em.
 
 Iterates through all the characters in the font, and calls I<code-ref>
 for each of them in turn.  Glyphs which don't correspond to Unicode
-characters are ignored.  There is currently no facility for iterating
-over all glyphs.
+characters are ignored.
 
 Each time your callback code is called, C<$_> will be set to a
 L<Font::FreeType::Glyph|Font::FreeType::Glyph> object for the current glyph.
 For an example see the program I<list-characters.pl> provided in the
 distribution.
 
-=item glyph_from_char(I<character>)
+=item foreach_glyph(I<code-ref>)
+
+Iterates through all the glyphs in the font, and calls I<code-ref>
+for each of them in turn.
+
+Each time your callback code is called, C<$_> will be set to a
+L<Font::FreeType::Glyph|Font::FreeType::Glyph> object for the current glyph.
+
+=item glyph_from_char(I<character>, I<fallback = 0>)
 
 Returns a L<Font::FreeType::Glyph|Font::FreeType::Glyph> object for the
 glyph corresponding to the first character in the string provided.
@@ -112,15 +121,38 @@ Note that currently non-ASCII characters are not likely to work with
 this, so you might be better using the C<glyph_from_char_code()>
 method below and the Perl C<ord> function.
 
-Returns I<undef> if the glyph is not available in the font.
+Returns I<undef> if the glyph is not available in the font and
+I<fallback> isn't defined; otherwise, i.e. if I<fallback = true>
+returns fonts I<missing glyph>.
 
-=item glyph_from_char_code(I<char-code>)
+=item glyph_from_char_code(I<char-code>, I<fallback = 0>)
 
 Returns a L<Font::FreeType::Glyph|Font::FreeType::Glyph> object for the
 glyph corresponding to Unicode character I<char-code>.  FreeType supports
 using other character sets, but this module doesn't yet.
 
-Returns I<undef> if the glyph is not available in the font.
+Returns I<undef> if the glyph is not available in the font and
+I<fallback> isn't defined; otherwise, i.e. if I<fallback = true>
+returns fonts I<missing glyph>.
+
+=item get_name_index(I<name>)
+
+Looks up a glyph by name and returns the index for that glyph in the
+font. Returns 0 if the name is not found.
+
+=item glyph_from_index(I<index>)
+
+Returns a L<Font::FreeType::Glyph|Font::FreeType::Glyph> object for the
+glyph at the given index.
+
+=item glyph_from_name(I<name>, I<fallback = 0>)
+
+Looks up a glyph by name and returns a
+L<Font::FreeType::Glyph|Font::FreeType::Glyph> object.
+
+Returns I<undef> if the glyph is not available in the font and
+I<fallback> isn't defined; otherwise, i.e. if I<fallback = true>
+returns fonts I<missing glyph>.
 
 =item has_glyph_names()
 
@@ -148,14 +180,15 @@ method below.
 =item has_reliable_glyph_names()
 
 True if the font contains reliable PostScript glyph names.  Some
-Some fonts contain bad glyph names.
+Some fonts contain bad glyph names.  This method always returns false
+when used with Freetype versions earlier than 2.1.1.
 
 See also C<has_glyph_names()> above.
 
 =item height()
 
-The height of the text.  Not entirely sure what that corresponds
-to (is it the line height or what?).
+The line height of the text, i.e. distance between baselines of two
+lines of text.
 
 =item is_bold()
 
@@ -222,6 +255,14 @@ Leave the measurements in font units, without scaling, and without hinting.
 
 =back
 
+=item load_flags()
+
+Retrieve the I<load_flags> option used.
+
+=item load_flags(I<load_flags>)
+
+Setting the I<load_flags> option. Returns the newly set value.
+
 =item number_of_faces()
 
 The number of faces contained in the file from which this one
@@ -248,10 +289,9 @@ to PostScript points.
 
 =item set_pixel_size(I<width>, I<height>)
 
-Set the size at which bitmapped fonts will be loaded.  Usually not
-necessary: by default most bitmap fonts will come out at the native
-size.  I think this is intended for selecting between embedded bitmaps
-in scalable fonts, but I'm not sure.
+Set the size at which bitmapped fonts will be loaded.  Bitmap fonts are
+automatically set to the first available standard size, so this usually
+isn't needed.
 
 =item style_name()
 
@@ -273,12 +313,25 @@ be used to scale font-specific measurements to the right size, although
 that's usually done for you by FreeType.  Usually this is 2048 for
 TrueType fonts.
 
+=item charmap()
+
+The current active L<charmap|Font::FreeType::CharMap> for this face.
+
+=item charmaps()
+
+An array of the L<charmaps|Font::FreeType::CharMap> of the face.
+
+=item bounding_box()
+
+The outline's L<bounding box|Font::FreeType::BoundingBox> for this face.
+
 =back
 
 =head1 SEE ALSO
 
 L<Font::FreeType|Font::FreeType>,
 L<Font::FreeType::Glyph|Font::FreeType::Glyph>
+L<Font::FreeType::CharMap>
 
 =head1 AUTHOR
 
